`puzzle_generator`
==================

[![Quality Gate Status](https://sonarcloud.io/api/project_badges/measure?project=vil02_puzzle_generator&metric=alert_status)](https://sonarcloud.io/summary/new_code?id=vil02_puzzle_generator)
[![codecov](https://codecov.io/gh/vil02/puzzle_generator/graph/badge.svg?token=C4HUFJ9QJH)](https://codecov.io/gh/vil02/puzzle_generator)
[![CodeFactor](https://www.codefactor.io/repository/github/vil02/puzzle_generator/badge)](https://www.codefactor.io/repository/github/vil02/puzzle_generator)
[![Codacy Badge](https://app.codacy.com/project/badge/Grade/0f53341a63914f1f9656782bff0e5089)](https://app.codacy.com/gh/vil02/puzzle_generator/dashboard?utm_source=gh&utm_medium=referral&utm_content=&utm_campaign=Badge_grade)

Basic functionality of
[`puzzle_generator`](https://github.com/vil02/puzzle_generator)
it to generate a piece of python code representing a puzzle/quiz.
The upcoming questions are stored in an encrypted form,
so it is _difficult_ to read them before providing correct answers.
The output is a single file without any dependencies.

[Examples](https://github.com/vil02/puzzle_generator/tree/master/examples)
and documentation can be found on [GitHub](https://github.com/vil02/puzzle_generator).
